# Hardware configuration file common to ASUS 701 EeePC4G-BK004
{
  config,
  lib,
  pkgs,
  ...
}: {
  imports = [
    <nixpkgs/nixos/modules/installer/scan/not-detected.nix>
    ../profiles/host_common.nix
    ../profiles/powerManagement.nix
    ../profiles/server_common.nix
  ];

  boot = {
    initrd = {
      availableKernelModules = [
        "ata_piix"
        "ehci_pci"
        "sd_mod" # SCSI disk support
        "uhci_hcd"
        "usb_storage" # USB Mass Storage support
      ];
    };
    loader = {
      grub = {
        enable = true;
        version = 2;
        device = "/dev/sdb";
      };
    };
  };

  nixpkgs = {
    config = {
      allowUnfree = true;
      packageOverrides = pkgs: {
        stdenv =
          pkgs.stdenv
          // {
            platform =
              pkgs.stdenv.platform
              // {
                kernelExtraConfig = ''
                  HIGHMEM64G? n  # 32-bit proc with > 4G RAM
                  HIGHMEM4G y    # 32-bit proc with =< 4G RAM
                '';
              };
          };
      };
    };
    localSystem = {
      # Ensure the right package architecture is used
      system = "i686-linux";
      config = "i686-unknown-linux-gnu";
    };
  };

  fileSystems."/" = {
    device = "/dev/disk/by-label/nixos";
    fsType = "ext4";
  };

  swapDevices = [{device = "/dev/disk/by-label/swap";}];

  networking.wireless.enable = true; # Enable wireless via wpa_supplicant.
  nix.settings.max-jobs = lib.mkDefault 1;
}
