# NixOps configuration for deploying the mcwhirter.io website
{
  config,
  pkgs,
  ...
}: let
  sources = import ../nix/sources.nix;
  mcwhirter-io = import sources.mcwhirter-io {};
  webdomain = "mcwhirter.io";
in {
  environment.sessionVariables = {
    LOCALE_ARCHIVE = "/run/current-system/sw/lib/locale/locale-archive";
  };

  services.nginx = {
    enable = true; # Enable Nginx
    recommendedGzipSettings = true;
    recommendedOptimisation = true;
    recommendedProxySettings = true;
    recommendedTlsSettings = true;
    virtualHosts = {
      "${webdomain}" = {
        # website hostname
        enableACME = true; # Use ACME certs
        forceSSL = true; # Force SSL
        root = "${mcwhirter-io}"; # Wesbite root
      };
      "www.${webdomain}" = {
        # Respect our elders :-)
        locations."/".extraConfig = "return 301 $scheme://${webdomain}$request_uri;";
      };
    };
  };

  security.acme = {
    acceptTerms = true;
    certs = {
      "${webdomain}" = {
        email = "admin@${webdomain}";
        group = "matrix-synapse";
      };
    };
  };

  networking.firewall.allowedTCPPorts = [80 443];
}
